@@ -23,19 +23,19 @@ Some black magic for inline callbacks.
 import eventlet  # noqa
 eventlet.monkey_patch(os=False)  # noqa
 
-import functools
-import inspect
-import mock
-import os
+import functools   # noqa: E402
+import inspect   # noqa: E402
+import os   # noqa: E402
+from unittest import mock   # noqa: E402
 
-import fixtures
-from oslo_concurrency import lockutils
-from oslo_config import cfg
-from oslo_config import fixture as config_fixture
-from oslo_log.fixture import logging_error
-import testtools
+import fixtures   # noqa: E402
+from oslo_concurrency import lockutils   # noqa: E402
+from oslo_config import cfg   # noqa: E402
+from oslo_config import fixture as config_fixture   # noqa: E402
+from oslo_log.fixture import logging_error   # noqa: E402
+import testtools   # noqa: E402
 
-from oslo_versionedobjects.tests import obj_fixtures
+from oslo_versionedobjects.tests import obj_fixtures   # noqa: E402
 
 
 CONF = cfg.CONF
@@ -178,8 +178,8 @@ class TestCase(testtools.TestCase):
                          baseclass)
 
         for name in sorted(implmethods.keys()):
-            baseargs = inspect.getargspec(basemethods[name])
-            implargs = inspect.getargspec(implmethods[name])
+            baseargs = inspect.getfullargspec(basemethods[name])
+            implargs = inspect.getfullargspec(implmethods[name])
 
             self.assertEqual(baseargs, implargs,
                              "%s args don't match base class %s" %
