@@ -14,10 +14,10 @@
 #    under the License.
 
 import datetime
+from unittest import mock
 import warnings
 
 import iso8601
-import mock
 import netaddr
 import testtools
 
@@ -223,7 +223,8 @@ class TestMACAddress(TestField):
         pattern = schema['pattern']
         for _, valid_val in self.coerce_good_values:
             self.assertRegex(valid_val, pattern)
-        invalid_vals = [x for x in self.coerce_bad_values if type(x) == 'str']
+        invalid_vals = [x for x in self.coerce_bad_values
+                        if isinstance(x, str)]
         for invalid_val in invalid_vals:
             self.assertNotRegex(invalid_val, pattern)
 
@@ -255,7 +256,8 @@ class TestPCIAddress(TestField):
         pattern = schema['pattern']
         for _, valid_val in self.coerce_good_values:
             self.assertRegex(valid_val, pattern)
-        invalid_vals = [x for x in self.coerce_bad_values if type(x) == 'str']
+        invalid_vals = [x for x in self.coerce_bad_values
+                        if isinstance(x, str)]
         for invalid_val in invalid_vals:
             self.assertNotRegex(invalid_val, pattern)
 
@@ -283,7 +285,7 @@ class TestUUID(TestField):
             ('da66a411-af0e-4829-9b67-475017ddz152',
                 'da66a411-af0e-4829-9b67-475017ddz152'),
             ('fake_uuid', 'fake_uuid'),
-            (u'fake_uāid', u'fake_uāid'),
+            ('fake_uāid', 'fake_uāid'),
             (b'fake_u\xe1id'.decode('latin_1'),
                 b'fake_u\xe1id'.decode('latin_1')),
             ('1', '1'),
@@ -292,11 +294,12 @@ class TestUUID(TestField):
         self.to_primitive_values = self.coerce_good_values[0:1]
         self.from_primitive_values = self.coerce_good_values[0:1]
 
-    def test_validation_enabled(self):
-
-        self.test_coerce_good_values()
-        self.test_from_primitive()
-        self.test_to_primitive()
+    @mock.patch('warnings.warn')
+    def test_coerce_good_values(self, mock_warn):
+        super().test_coerce_good_values()
+        mock_warn.assert_has_calls(
+            [mock.call(mock.ANY, FutureWarning)] * 8,
+        )
 
     def test_validation_warning_can_be_escalated_to_exception(self):
         warnings.filterwarnings(action='error')
@@ -311,7 +314,8 @@ class TestUUID(TestField):
         pattern = schema['pattern']
         for _, valid_val in self.coerce_good_values[:4]:
             self.assertRegex(valid_val, pattern)
-        invalid_vals = [x for x in self.coerce_bad_values if type(x) == 'str']
+        invalid_vals = [x for x in self.coerce_bad_values
+                        if isinstance(x, str)]
         for invalid_val in invalid_vals:
             self.assertNotRegex(invalid_val, pattern)
 
